aboutsummaryrefslogtreecommitdiffstats
path: root/core_internal.h
diff options
context:
space:
mode:
authorMark Farrugia <mark.farrugia@fiberdyne.com.au>2018-10-08 12:06:46 +1100
committerMark Farrugia <mark.farrugia@fiberdyne.com.au>2018-10-26 17:27:39 +1100
commit1b8e8c7a0b998e9e458094e5f1b7b60bc1c4b297 (patch)
treeed61c88ecb60a872103d9d9bf153ba6532d0631f /core_internal.h
parent85510ff4540c13609b3ec749a80638ae502fd098 (diff)
Refactor avirt_card_register, move PCM creation to it.
When creating the PCMs we need information regarding the stream's mapping. For the loopback, we need to add both playback and capture substreams. Signed-off-by: Mark Farrugia <mark.farrugia@fiberdyne.com.au>
Diffstat (limited to 'core_internal.h')
-rw-r--r--core_internal.h5
1 files changed, 2 insertions, 3 deletions
diff --git a/core_internal.h b/core_internal.h
index 5979a50..1ab8d3c 100644
--- a/core_internal.h
+++ b/core_internal.h
@@ -37,10 +37,10 @@ int __init __avirt_configfs_init(struct avirt_core *core);
void __exit __avirt_configfs_exit(struct avirt_core *core);
/**
* __avirt_card_register - Register the sound card to user space
* @return: 0 on success, negative ERRNO on failure
*/
-int __avirt_card_register(void);
+int __avirt_streams_seal(void);
/**
* __avirt_streams_sealed - Check whether the streams have been sealed or not
@@ -49,7 +49,6 @@ int __avirt_card_register(void);
bool __avirt_streams_sealed(void);
/**
-/**
* __avirt_stream_find_by_device - Get audio stream from device number
* @device: The PCM device number corresponding to the desired stream
* @return: The audio stream if found, or an error pointer otherwise
@@ -37,10 +37,10 @@ int __init __avirt_configfs_init(struct avirt_core *core);
void __exit __avirt_configfs_exit(struct avirt_core *core);
/**
- * __avirt_card_register - Register the sound card to user space
+ * __avirt_streams_seal - Register the sound card to user space
* @return: 0 on success, negative ERRNO on failure
*/